OiRA

Help

1. Preparació
2. Implicació
3. Identificació + Avaluació
   1. 1 Commercial manned guarding
   2. Ω Riscos afegits (per vostè)
      1. Ω.1 The entrance floor is often wet
   - No respost
   - Posposat
   - Correcte
   - Actuar
4. Pla d'acció
5. Informe
6. Grau d’emplenament 0%

Si heu identificat riscos no inclosos a l'eina, els podeu afegir ara:

Important: Per evitar que hi hagi riscos duplicats, és molt recomanable que primer resseguiu tots els mòduls anteriors, si encara no ho heu fet.

Si no necessiteu afegir riscos, si us plau, continueu.

Anterior Continuar amb el pla d’acció

Scroll to top
Back

## other-risks.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More